==> nextcloud-30.0.14.tgz: nextcloud/apps/files_downloadlimit/l10n/sw.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Ukomo wa upakuaji wa faili",
    "File link share download limit" : "Kikomo cha upakuaji wa kiungo cha faili",
    "This app allows limiting the number of downloads for external link shares." : "Programu hii inaruhusu kupunguza idadi ya vipakuliwa vya kushiriki kwa viungo vya nje.",
    "The minimum limit is 1" : "Kiwango cha chini cha ukomo ni 1",
    "Failed to set download limit" : "Imeshindwa kupangilia ukomo wa upakuaji",
    "Failed to remove download limit" : "Imeshindwa kuondoa ukomo wa upakuaji",
    "Limit downloads" : "Punguza upakuaji",
    "Set download limit" : "Pangilia ukomo wa apakuaji",
    "Setting a new limit will reset the download count" : "Kuweka kikomo kipya kutaweka upya hesabu ya upakuaji",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 remaining download allowed","{count}vipakuliwa vilivyosalia vinaruhusiwa "],
    "Failed to set default download limit" : "Imeshindwa kuweka kikomo chaguomsingi cha upakuaji",
    "Download limit" : "Ukomo wa upakuaji",
    "Configure the default download limit for external shares." : "Sanidi kikomo chaguo-msingi cha upakuaji kwa hisa za nje.",
    "Set default download limit" : "Pangilia chaguo msingi la ukomo wa upakuaji",
    "You have reached the maximum amount of downloads allowed" : "Umefikia kiwango cha juu zaidi cha upakuaji unaoruhusiwa",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Shiriki hii ina idadi ndogo ya vipakuliwa. Je, una uhakika unataka kuanzisha upakuaji mpya?"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-31.0.10.tgz: nextcloud/apps/files_downloadlimit/l10n/sw.js <==
OC.L10N.register(
    "files_downloadlimit",
    {
    "Files download limit" : "Ukomo wa upakuaji wa faili",
    "File link share download limit" : "Kikomo cha upakuaji wa kiungo cha faili",
    "This app allows limiting the number of downloads for external link shares." : "Programu hii inaruhusu kupunguza idadi ya vipakuliwa vya kushiriki kwa viungo vya nje.",
    "The minimum limit is 1" : "Kiwango cha chini cha ukomo ni 1",
    "Failed to set download limit" : "Imeshindwa kupangilia ukomo wa upakuaji",
    "Failed to remove download limit" : "Imeshindwa kuondoa ukomo wa upakuaji",
    "Limit downloads" : "Punguza upakuaji",
    "Set download limit" : "Pangilia ukomo wa apakuaji",
    "Setting a new limit will reset the download count" : "Kuweka kikomo kipya kutaweka upya hesabu ya upakuaji",
    "_1 remaining download allowed_::_{count} remaining downloads allowed_" : ["1 remaining download allowed","{count}vipakuliwa vilivyosalia vinaruhusiwa "],
    "Download limit" : "Ukomo wa upakuaji",
    "Configure the default download limit for external shares." : "Sanidi kikomo chaguo-msingi cha upakuaji kwa hisa za nje.",
    "Default download limit for external shares" : "Kikomo chaguomsingi cha upakuaji kwa shiriki za nje",
    "Set default download limit" : "Pangilia chaguo msingi la ukomo wa upakuaji",
    "You have reached the maximum amount of downloads allowed" : "Umefikia kiwango cha juu zaidi cha upakuaji unaoruhusiwa",
    "This share has a limited number of downloads. Are you sure you want to trigger a new download?" : "Shiriki hii ina idadi ndogo ya vipakuliwa. Je, una uhakika unataka kuanzisha upakuaji mpya?",
    "Failed to set default download limit" : "Imeshindwa kuweka kikomo chaguomsingi cha upakuaji",
    "Failed to remove default download limit" : "Imeshindwa kuondoa kikomo chaguomsingi cha upakuaji"
},
"nplurals=2; plural=(n != 1);");
